# Welcome to gtlparser


[![image](https://img.shields.io/pypi/v/gtlparser.svg)](https://pypi.python.org/pypi/gtlparser)


**A python package for Google Time Line data analysis**


-   Free software: MIT License
-   Documentation: <https://GGweelplay.github.io/gtlparser>


## Features

-   Parse Google Time Line JSON to GEOJSON
-   Great too for GIS